@@ -153,6 +153,7 @@ def copy_qt_files(
 ) -> None:
     """Helper function to copy Qt plugins, resources, translations, etc."""
     for source_path, target_path in _get_qt_files(name, variable, arg):
+        finder.lib_files[source_path] = target_path.as_posix()
         finder.include_files(source_path, target_path)
 
 
@@ -190,8 +191,15 @@ def load_qt_qtcore(finder: ModuleFinder, module: Module) -> None:
     """Include plugins for the module."""
     name = _qt_implementation(module)
     variable = "BinariesPath" if IS_WINDOWS else "LibrariesPath"
-    for source, target in _get_qt_files(name, variable, "*"):
-        finder.lib_files[source] = target
+    if IS_MINGW or IS_WINDOWS:
+        patterns = ["Qt*.dll"]
+    else:
+        patterns = ["Qt*.so*"]
+        if IS_MACOS:
+            patterns.append("Qt*.dylib")
+    for pattern in patterns:
+        for source, target in _get_qt_files(name, variable, pattern):
+            finder.lib_files.setdefault(source, target.as_posix())
 
 
 def load_qt_qtdesigner(finder: ModuleFinder, module: Module) -> None:
@@ -394,12 +402,13 @@ def load_qt_qtwebenginecore(finder: ModuleFinder, module: Module) -> None:
         if environment == "conda":  # conda-forge Linux and macOS
             prefix = Path(sys.prefix)
             conda_meta = prefix / "conda-meta"
-            pkg = next(conda_meta.glob("nss-*.json"))
-            files = json.loads(pkg.read_text(encoding="utf_8"))["files"]
-            for file in files:
-                source = prefix / file
-                if source.match("lib*.so") or source.match("lib*.dylib"):
-                    finder.include_files(source, f"lib/{source.name}")
+            pkg = next(conda_meta.glob("nss-*.json"), None)
+            if pkg is not None:
+                files = json.loads(pkg.read_text(encoding="utf_8"))["files"]
+                for file in files:
+                    source = prefix / file
+                    if source.match("lib*.so") or source.match("lib*.dylib"):
+                        finder.include_files(source, f"lib/{source.name}")
         else:
             copy_qt_files(finder, name, "LibraryExecutablesPath", "libnss*.*")
 
